==> deepin-home_1.0.6.orig.tar.xz: deepin-home-1.0.6/translations/deepin-home/ast.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="163"/>
        <source>Community News</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="29"/>
        <source>Version: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="30"/>
        <source>Deepin Messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="66"/>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="101"/>
        <source>Sign in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="113"/>
        <source>Sign out</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="146"/>
        <source>%1 messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="150"/>
        <source>Mark all as read</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="113"/>
        <source>Expired on: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="118"/>
        <source>Fill In</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-home_1.0.15.orig.tar.xz: deepin-home-1.0.15/translations/deepin-home/ast.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Communication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="52"/>
        <source>Discuss and share here</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Bug Report</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="62"/>
        <source>Report issues you found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="70"/>
        <source>Submit your suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="84"/>
        <source>Resources</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="89"/>
        <source>Questionaire</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="146"/>
        <source>Join US</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="151"/>
        <source>Internal Testing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="165"/>
        <source>Community News</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="282"/>
        <source>Network error, please try later</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="83"/>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="119"/>
        <source>Sign in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="131"/>
        <source>Sign out</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="149"/>
        <source>%1 messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="153"/>
        <source>Mark all as read</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <location filename="../src/preloadplugin/Preload.qml" line="36"/>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="89"/>
        <source>Expired on: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="117"/>
        <source>Fill In</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
